@@ -2,9 +2,9 @@
 #
 # Initial policy generator.
 #
-# Copyright (C) 2005-2008  NTT DATA CORPORATION
+# Copyright (C) 2005-2009  NTT DATA CORPORATION
 #
-# Version: 1.6.2   2008/06/25
+# Version: 1.6.8   2009/05/28
 #
 
 cd ${0%/*}
@@ -114,6 +114,8 @@ make_exception() {
 	done
 	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/'
 	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/\X'
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/defer/\x/'
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/defer/\x/\X'
 	
 	#
 	# Make patterns for man(1).
@@ -519,6 +521,13 @@ make_exception() {
 	    echo 'file_pattern /var/lib/init.d/treecache.\?\?\?\?\?\?\?'
 	fi
 	
+	echo 'file_pattern /etc/group.\$'
+	echo 'file_pattern /etc/gshadow.\$'
+	echo 'file_pattern /etc/passwd.\$'
+	echo 'file_pattern /etc/shadow.\$'
+	echo 'file_pattern /var/cache/logwatch/logwatch.\*/'
+	echo 'file_pattern /var/cache/logwatch/logwatch.\*/\*'
+	echo 'file_pattern /var/tmp/sqlite_\*'
 	echo 'file_pattern /tmp/ib\?\?\?\?\?\?'
 	echo 'file_pattern /tmp/PerlIO_\?\?\?\?\?\?'
 	[ -d /var/run/hald/ ] && echo 'file_pattern /var/run/hald/acl-list.\?\?\?\?\?\?'
@@ -608,6 +617,7 @@ EOF
 		cat > /etc/ccs/profile.conf << EOF
 0-COMMENT=-----Disabled Mode-----
 0-MAC_FOR_FILE=disabled
+0-MAC_FOR_IOCTL=disabled
 0-MAC_FOR_ARGV0=disabled
 0-MAC_FOR_ENV=disabled
 0-MAC_FOR_NETWORK=disabled
@@ -656,6 +666,7 @@ EOF
 0-MAC_FOR_CAPABILITY::SYS_PTRACE=disabled
 1-COMMENT=-----Learning Mode-----
 1-MAC_FOR_FILE=learning
+1-MAC_FOR_IOCTL=learning
 1-MAC_FOR_ARGV0=learning
 1-MAC_FOR_ENV=learning
 1-MAC_FOR_NETWORK=learning
@@ -704,6 +715,7 @@ EOF
 1-MAC_FOR_CAPABILITY::SYS_PTRACE=learning
 2-COMMENT=-----Permissive Mode-----
 2-MAC_FOR_FILE=permissive
+2-MAC_FOR_IOCTL=permissive
 2-MAC_FOR_ARGV0=permissive
 2-MAC_FOR_ENV=permissive
 2-MAC_FOR_NETWORK=permissive
@@ -752,6 +764,7 @@ EOF
 2-MAC_FOR_CAPABILITY::SYS_PTRACE=permissive
 3-COMMENT=-----Enforcing Mode-----
 3-MAC_FOR_FILE=enforcing
+3-MAC_FOR_IOCTL=enforcing
 3-MAC_FOR_ARGV0=enforcing
 3-MAC_FOR_ENV=enforcing
 3-MAC_FOR_NETWORK=enforcing
@@ -806,7 +819,10 @@ fi
 if [ ! -r /etc/ccs/exception_policy.conf ]; then
 	echo Creating exception policy. This will take several minutes.
 	make_exception > /etc/ccs/exception_policy.conf
-	make_alias >> /etc/ccs/exception_policy.conf
+	### Old version. ###
+	# make_alias >> /etc/ccs/exception_policy.conf
+	### New version. ###
+	./make_alias | grep -v '/[SK][0-9][0-9]' >> /etc/ccs/exception_policy.conf
 fi
 if [ ! -r /etc/ccs/system_policy.conf ]; then
 	echo Creating system policy.
